@@ -9,7 +9,7 @@ import numpy as np
 
 
 class ModelAnalyzer(BaseModule):
-    
+
     def run(self):
         np.seterr(divide='warn', invalid='warn')
         """
@@ -21,14 +21,18 @@ class ModelAnalyzer(BaseModule):
 
         # Make predictions on the validation dataset normally and with various columns missing
         normal_predictions = self.transaction.model_backend.predict('validate')
+        normal_predictions_test = self.transaction.model_backend.predict('test')
         normal_accuracy = evaluate_accuracy(normal_predictions, self.transaction.input_data.validation_df, self.transaction.lmd['stats_v2'], output_columns)
 
         empty_input_predictions = {}
         empty_inpurt_accuracy = {}
 
+        empty_input_predictions_test = {}
+
         ignorable_input_columns = [x for x in input_columns if self.transaction.lmd['stats_v2'][x]['typing']['data_type'] != DATA_TYPES.FILE_PATH and x not in [y[0] for y in self.transaction.lmd['model_order_by']]]
         for col in ignorable_input_columns:
             empty_input_predictions[col] = self.transaction.model_backend.predict('validate', ignore_columns=[col])
+            empty_input_predictions_test[col] = self.transaction.model_backend.predict('test', ignore_columns=[col])
             empty_inpurt_accuracy[col] = evaluate_accuracy(empty_input_predictions[col], self.transaction.input_data.validation_df, self.transaction.lmd['stats_v2'], output_columns)
 
         # Get some information about the importance of each column
@@ -90,9 +94,9 @@ class ModelAnalyzer(BaseModule):
 
         for col in output_columns:
             pval = ProbabilisticValidator(col_stats=self.transaction.lmd['stats_v2'][col], col_name=col, input_columns=input_columns)
-            predictions_arr = [normal_predictions] + [empty_input_predictions[col] for col in ignorable_input_columns]
+            predictions_arr = [normal_predictions_test] + [x for x in empty_input_predictions_test.values()]
 
-            pval.fit(self.transaction.input_data.validation_df, predictions_arr, [[x] for x in ignorable_input_columns])
+            pval.fit(self.transaction.input_data.test_df, predictions_arr, [[ignored_column] for ignored_column in empty_input_predictions_test])
             overall_accuracy, accuracy_histogram, cm, accuracy_samples = pval.get_accuracy_stats()
             overall_accuracy_arr.append(overall_accuracy)
 
