@@ -192,22 +192,22 @@ class TypeDeductor(BaseModule):
             curr_data_type = max_known_dtype
 
             possible_subtype_counts = [(k, v) for k, v in subtype_dist.items()
-                                    if k in DATA_TYPES_SUBTYPES.subtypes[curr_data_type]]
+                                    if k in DATA_TYPES_SUBTYPES[curr_data_type]]
             curr_data_subtype, _ = max(possible_subtype_counts,
                                     key=lambda pair: pair[0])
         else:
             curr_data_type, curr_data_subtype = None, None
 
-        # Categorical
+        # Categorical based on unique values
         if curr_data_type != DATA_TYPES.DATE:
-            if nr_distinct_vals < (nr_vals / 20):
+            if nr_distinct_vals < (nr_vals / 20) or nr_distinct_vals < 6:
                 if (curr_data_type != DATA_TYPES.NUMERIC) or (nr_distinct_vals < 20):
                     if curr_data_type is not None:
                         additional_info['other_potential_types'].append(curr_data_type)
                         additional_info['other_potential_subtypes'].append(curr_data_subtype)
                     curr_data_type = DATA_TYPES.CATEGORICAL
 
-        # If curr_data_type is still None, then it's text
+        # If curr_data_type is still None, then it's text or category
         if curr_data_type is None:
             lang_dist = get_language_dist(data)
 
@@ -219,18 +219,22 @@ class TypeDeductor(BaseModule):
             if lang_dist['Unknown'] > 0.5:
                 curr_data_type = DATA_TYPES.CATEGORICAL
             else:
-                curr_data_type = DATA_TYPES.TEXT
+                nr_words, word_dist, nr_words_dist = analyze_sentences(data)
 
-                nr_words, word_dist, _, = analyze_sentences(data)
-
-                if len(word_dist) > 500 and nr_words / len(data) > 5:
-                    curr_data_subtype = DATA_SUBTYPES.RICH
+                if 1 in nr_words_dist and nr_words_dist[1] == nr_words:
+                    curr_data_type = DATA_TYPES.CATEGORICAL
                 else:
-                    curr_data_subtype = DATA_SUBTYPES.SHORT
+                    curr_data_type = DATA_TYPES.TEXT
+                    
+                    if len(word_dist) > 500 and nr_words / len(data) > 5:
+                        curr_data_subtype = DATA_SUBTYPES.RICH
+                    else:
+                        curr_data_subtype = DATA_SUBTYPES.SHORT
 
-                type_dist = {curr_data_type: len(data)}
-                subtype_dist = {curr_data_subtype: len(data)}
-                return curr_data_type, curr_data_subtype, type_dist, subtype_dist, additional_info
+                    type_dist = {curr_data_type: len(data)}
+                    subtype_dist = {curr_data_subtype: len(data)}
+
+                    return curr_data_type, curr_data_subtype, type_dist, subtype_dist, additional_info
 
         if curr_data_type == DATA_TYPES.CATEGORICAL:
             if nr_distinct_vals > 2:
